@@ -18,22 +18,19 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-================================================================================
-
-	The NoteContainer provides a container for the mingus.containers.Note
-	objects. It can be used to store single and multiple notes and is 
-	required for working with Bars.
-
 ================================================================================
 
 """
 
 from Note import Note
-from mingus.core import intervals
+from mingus.core import intervals, chords
 from mt_exceptions import UnexpectedObjectError
 
 class NoteContainer:
-	"""An interface for things containing notes."""
+	"""The !NoteContainer provides a container for the \
+[refMingusContainersNote mingus.containers.Note] objects. \
+It can be used to store single and multiple notes in and is \
+required for working with [refMingusContainersBar Bars]."""
 
 	notes = []
 
@@ -42,13 +39,13 @@ class NoteContainer:
 		self.add_notes(notes)
 
 	def empty(self):
-		"""Empties the container"""
+		"""Empties the container."""
 		self.notes = []
 
 	def add_note(self, note, octave = 4, dynamics = {}):
-		"""Adds a note to the container and sorts the notes from low
-		to high. The note can either be a string, in which case you could
-		also use the octave and dynamics arguments, or a Note object."""
+		"""Adds a note to the container and sorts the notes from low \
+to high. The note can either be a string, in which case you could \
+also use the octave and dynamics arguments, or a Note object."""
 
 		if type(note) == str:
 			note = Note(note, octave, dynamics)
@@ -65,12 +62,16 @@ class NoteContainer:
 		return self.notes
 
 	def add_notes(self, notes):
-		"""Feeds notes to self.add_note. The notes can either be an other
-		NoteContainer, a list of Note objects or strings or a list of lists 
-		formatted like this:
-			notes = [["C", 5], ["E", 5], ["G", 6]] 
-		or even:
-			notes = [["C", 5, {"volume" : 20}], ["E", 6, {"volume":20}]]"""
+		"""Feeds notes to self.add_note. The notes can either be an other \
+!NoteContainer, a list of [refMingusContainersNote Note] objects or \
+strings or a list of lists formatted like this: 
+{{{
+notes = [["C", 5], ["E", 5], ["G", 6]] 
+}}}
+	or even:
+{{{
+notes = [["C", 5, {"volume" : 20}], ["E", 6, {"volume":20}]]
+}}}"""
 		if hasattr(notes, "notes"):
 			for x in notes.notes:
 				self.add_note(x)
@@ -78,6 +79,9 @@ class NoteContainer:
 		elif hasattr(notes, "name"):
 			self.add_note(notes)
 			return self.notes
+		elif type(notes) == str:
+			self.add_note(notes)
+			return self.notes
 
 		for x in notes:
 			if type(x) == list and len(x) != 1:
@@ -90,9 +94,10 @@ class NoteContainer:
 		return self.notes
 
 	def remove_note(self, note, octave = -1):
-		"""Removes note from container. The note can either be a Note 
-		object or a string representing the note's name. If no specific 
-		octave is given, the note gets removed in every octave."""
+		"""Removes note from container. The note can either be a \
+[refMingusContainersNote Note] object or a string representing the \
+note's name. If no specific octave is given, the note gets removed \
+in every octave."""
 
 		res = []
 		for x in self.notes:
@@ -109,16 +114,22 @@ class NoteContainer:
 		return res
 
 	def remove_notes(self, notes):
-		for x in notes:
-			if type(x) == list and len(x) != 1:
-				if len(x) == 2:
-					self.remove_note(x[0], x[1])
-			else:
-				self.remove_note(x)
-		return self.notes
+		"""Removes notes from the containers. This function accepts \
+a list of [refMingusContainersNote Note] objects or notes as strings \
+and also single strings or [refMingusContainersNote Note] objects."""
+
+		if type(notes) == str:
+			return self.remove_note(notes)
+		elif hasattr(notes, "name"):
+			return self.remove_note(notes)
+		else:
+			map(lambda x: self.remove_note(x), notes)
+			return self.notes
+
 
 	def remove_duplicate_notes(self):
-		"""Removes duplicate and enharmonic notes from the container"""
+		"""A helper function that removes duplicate and \
+enharmonic notes from the container"""
 		res = []
 		for x in self.notes:
 			if x not in res:
@@ -130,26 +141,61 @@ class NoteContainer:
 		"""Sorts the notes in the container from low to high."""
 		self.notes.sort()
 
+	def augment(self):
+		"""Augments all the notes in the !NoteContainer"""
+		for n in self.notes:
+			n.augment()
+
+	def diminish(self):
+		"""Diminishes all the notes in the !NoteContainer"""
+		for n in self.notes:
+			n.diminish()
+
+	def to_minor(self):
+		"""Converts all the notes in the container to their minor \
+equivalent."""
+		for n in self.notes:
+			n.to_minor()
+
+	def to_major(self):
+		"""Converts all the notes in the container to their major \
+equivalent."""
+		for n in self.notes:
+			n.to_major()
+
+	def determine(self, shorthand = False):
+		"""Determines the type of chord or interval currently in \
+the container"""
+		note_list = []
+		for n in self.notes:
+			if n.name not in note_list:
+				note_list.append(n.name)
+		return chords.determine(note_list, shorthand)
+
 	def __repr__(self):
-		"""A nice and clean representation of the note container"""
+		"""A nice and clean string representation of the note container"""
 		return str(self.notes)
 
 	def __getitem__(self, item):
 		"""This method allows you to use the container as a simple array.
-		Example:
-			>>> n = NoteContainer(["C", "E", "G"])
-			>>> n[0]
-			'C-5' 
+	Example:
+{{{
+>>> n = NoteContainer(["C", "E", "G"])
+>>> n[0]
+'C-5' 
+}}}
 		"""
 		return self.notes[item]
 
 	def __setitem__(self, item, value):
-		"""This allows you to use [] notation on NoteContainers. This 
-		function accepts Notes and notes as string.
-		Examples:
-			>>> n = NoteContainer(["C", "E", "G"])
-			>>> n[0] = "B"
-			["B-5", "E-5", "G-5"] """
+		"""This allows you to use [] notation on !NoteContainers. This \
+function accepts Notes and notes as string.
+	Examples:
+{{{
+>>> n = NoteContainer(["C", "E", "G"])
+>>> n[0] = "B"
+["B-5", "E-5", "G-5"] 
+}}}"""
 
 		if type(value) == str:
 			n = Note(value)
@@ -159,22 +205,24 @@ class NoteContainer:
 		return self.notes
 
 	def __add__(self, notes):
-		"""This method allows you to use '+' notation on NoteContainers.
-		Example:
-			>>> n = NoteContainer(["C", "E", "G"])
-			>>> n + "B"
-			["C-5", "E-5", "G-5", "B-5"] 
-		"""
+		"""This method allows you to use '+' notation on !NoteContainers. 
+	Example:
+{{{
+>>> n = NoteContainer(["C", "E", "G"])
+>>> n + "B"
+["C-5", "E-5", "G-5", "B-5"] 
+}}}"""
 		self.add_notes(notes)
 		return self.notes
 
 	def __sub__(self, notes):
-		"""This method allows you to use the '-' operator on NoteContainers.
-		Example:
-			>>> n = NoteContainer(["C", "E", "G"])
-			>>> n - "E"
-			["C-5", "G-5"]
-		"""
+		"""This method allows you to use the '-' operator on !NoteContainers.
+	Example:
+{{{
+>>> n = NoteContainer(["C", "E", "G"])
+>>> n - "E"
+["C-5", "G-5"]
+}}}"""
 		self.remove_notes(notes)
 		return self.notes
 
@@ -183,7 +231,7 @@ class NoteContainer:
 		return len(self.notes)
 
 	def __eq__(self, other):
-		"""Overloads the == operator for NoteContainer instances."""
+		"""Overloads the == operator for !NoteContainer instances."""
 		for x in self:
 			if x not in other:
 				return False
