@@ -287,7 +287,7 @@ def invert(interval):
 	interval.reverse()
 	return res
 
-def determine(note1, note2):
+def determine(note1, note2, shorthand = False):
 	"""Names the interval between note1 and note2.
 	Example:
 {{{
@@ -325,13 +325,21 @@ for 'major' fifths and fourths:
 		y = get_val(note2)
 
 		if x == y:
-			return "major unison"
+			if not shorthand:
+				return "major unison"
+			return "1"
 		elif x < y:
-			return "augmented unison"
+			if not shorthand:
+				return "augmented unison"
+			return "#1"
 		elif x - y == 1:
-			return "minor unison"
+			if not shorthand:
+				return "minor unison"
+			return "b1"
 		else:
-			return "diminished unison"
+			if not shorthand:
+				return "diminished unison"
+			return "bb1"
 
 	# Other intervals
 	n1 = notes.fifths.index(note1[0])
@@ -342,38 +350,98 @@ for 'major' fifths and fourths:
 	if n2 < n1:
 		number_of_fifth_steps = len(notes.fifths) - n1 + n2
 
-	# [name, half notes for major version of this interval]
+	# [name, shorthand_name, half notes for major version of this interval]
 	fifth_steps = [\
-		["unison", 0],
-		["fifth", 7],
-		["second", 2],
-		["sixth", 9],
-		["third", 4],
-		["seventh", 11],
-		["fourth", 5]]
+		["unison", "1", 0],
+		["fifth", "5", 7],
+		["second", "2", 2],
+		["sixth", "6", 9],
+		["third", "3", 4],
+		["seventh", "7", 11],
+		["fourth", "4", 5]]
 
+	# Count half steps between note1 and note2
 	half_notes = measure(note1, note2)
+	# Get the proper list from the number of fifth steps
 	current = fifth_steps[number_of_fifth_steps]
-	maj = current[1]
 
+	# maj = number of major steps for this interval
+	maj = current[2]
 
+	# if maj is equal to the half steps between note1 and note2
+	# the interval is major or perfect
 	if maj == half_notes:
 
 		# Corner cases for perfect fifths and fourths
 		if current[0] == "fifth":
-			return "perfect fifth"
+			if not shorthand:
+				return "perfect fifth"
 		elif current[0] == "fourth":
-			return "perfect fourth"
-		return "major " + current[0]
+			if not shorthand:
+				return "perfect fourth"
 
+		if not shorthand:
+			return "major " + current[0]
+		return current[1]
+
+	# if maj + 1 is equal to half_notes, the interval is augmented.
 	elif maj + 1 <= half_notes:
-		return "augmented " + current[0]
+		if not shorthand:
+			return "augmented " + current[0]
+		return "#" * (half_notes - maj) + current[1]
 
+	# etc.
 	elif maj - 1 == half_notes:
-		return "minor " + current[0]
+		if not shorthand:
+			return "minor " + current[0]
+		return "b" + current[1]
 
 	elif maj - 2 >= half_notes:
-		return "diminished " + current[0]
+		if not shorthand:
+			return "diminished " + current[0]
+		return "b" * (maj - half_notes) + current[1]
+
+
+def from_shorthand(note, interval):
+	"""Returns the note on interval.
+	Example:
+{{{
+>>> from_shorthand("A", "b3")
+'C'
+>>> from_shorthand("D", "2")
+'E'
+}}}"""
+	shorthand_lookup = [
+		["1", major_unison],
+		["2", major_second],
+		["3", major_third],
+		["4", major_fourth],
+		["5", major_fifth],
+		["6", major_sixth],
+		["7", major_seventh]
+					]
+
+	# Looking up last character in interval in shorthand_lookup
+	# and calling that function.
+	val = False
+	for shorthand in shorthand_lookup:
+		if shorthand[0] == interval[-1]:
+			val = shorthand[1](note)
+	
+	#warning Last character in interval should be 1-7
+	if val == False:
+		return False
+
+	# Collect accidentals
+	for x in interval:
+		if x == "#":
+			val = notes.augment(val)
+		elif x == "b":
+			val = notes.diminish(val)
+		else:
+			return val
+
+	
 
 
 
